@@ -18,7 +18,7 @@ ssl._create_default_https_context = ssl._create_unverified_context
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.32'
+__version__ = '0.1.33'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -34,6 +34,7 @@ __info__ = {
     '2022/06/26: 0.1.29 加入 my_addressable_IP()',
     '2022/06/29: 0.1.30 加入需要的module',
     '2022/07/02: 0.1.32 加入 DefaultOrderedDict'
+    '2022/07/13: 0.1.33 加入 binance_copy_bot'
 }
 
 _MYPYLIB_ROOT = os.path.abspath(os.path.dirname(__file__))
@@ -741,6 +742,12 @@ class tplaysound(threading.Thread):
 if __name__ == '__main__':
     from time import sleep
 
+    if True:
+        tline = tLineNotify(token='wZus5sTyCscdtmfvQRQpxYTaAdiXHb0OJpljUE1aDXb')
+        tline.send('測試')
+        tline.stop()
+
+
     if True:
         tps = tplaysound()
         index = 0
